@@ -37,8 +37,8 @@ else:
         soname = "libxcb.so"
 lib = ffi.dlopen(soname)
 
-__xcb_proto_version__ = "1.14"
-__version__ = "0.11.1"
+__xcb_proto_version__ = "1.14.1"
+__version__ = "0.12.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -126,10 +126,11 @@ class Unpacker(object):
     @classmethod
     def synthetic(cls, data, format):
         self = cls.__new__(cls)
+        self.__init__(len(data))
         self.buf = data
         self.offset = 0
         self.size = len(data)
-        self.size
+        return self
 
 
 class CffiUnpacker(Unpacker):
